@@ -30,7 +30,10 @@ CLI_CONFIG = {
         "subcommands": ["state", "exec"],
     },
     "acct_key": {"source": "acct", "os": "ACCT_KEY", "subcommands": ["state", "exec"]},
-    "acct_profile": {"os": "ACCT_PROFILE", "subcommands": ["state", "exec"],},
+    "acct_profile": {
+        "os": "ACCT_PROFILE",
+        "subcommands": ["state", "exec"],
+    },
 }
 
 CONFIG = {
@@ -42,7 +45,10 @@ CONFIG = {
         "default": False,
         "help": "Set the idem run to execute in test mode. No changes will be made, idem will only detect if changes will be made in a real run.",
     },
-    "tree": {"default": "", "help": "The directory containing sls files",},
+    "tree": {
+        "default": "",
+        "help": "The directory containing sls files",
+    },
     "cache_dir": {
         "default": "/var/cache/idem",
         "help": "The location to use for the cache directory",
@@ -55,10 +61,22 @@ CONFIG = {
         "default": "jinja|yaml",
         "help": "The render pipe to use, this allows for the language to be specified",
     },
-    "runtime": {"default": "serial", "help": "Select which execution runtime to use",},
-    "output": {"default": "idem", "help": "The outputter to use to display data",},
-    "sls": {"default": [], "help": "A space delimited list of sls refs to execute",},
-    "exec": {"default": "", "help": "The name of an execution function to execute",},
+    "runtime": {
+        "default": "serial",
+        "help": "Select which execution runtime to use",
+    },
+    "output": {
+        "default": None,
+        "help": "The outputter to use to display data",
+    },
+    "sls": {
+        "default": [],
+        "help": "A space delimited list of sls refs to execute",
+    },
+    "exec": {
+        "default": "",
+        "help": "The name of an execution function to execute",
+    },
     "exec_args": {
         "default": [],
         "help": "Arguments to pass to the named execution function",
