@@ -1,7 +1,9 @@
-# Import python libs
-import asyncio
+from typing import Any
+from typing import Dict
+from typing import Iterable
+from typing import Tuple
+
 from dict_tools import data
-from typing import Iterable, Any, Dict, Tuple
 
 __func_alias__ = {"ctx_": "ctx"}
 
@@ -28,9 +30,7 @@ async def run(
         args.insert(0, ctx)
 
     ret = func(*args, **kwargs)
-    if asyncio.iscoroutine(ret):
-        ret = await ret
-    return ret
+    return await hub.pop.loop.unwrap(ret)
 
 
 async def ctx_(
@@ -74,7 +74,7 @@ async def single(hub, path: str, *args, **kwargs):
     acct_key = hub.OPT.acct.acct_key
     acct_profile = hub.OPT.acct.get("acct_profile", hub.acct.DEFAULT)
 
-    return await hub.idem.ex.run(
+    ret = await hub.idem.ex.run(
         path,
         args=args,
         kwargs=kwargs,
@@ -82,3 +82,4 @@ async def single(hub, path: str, *args, **kwargs):
         acct_key=acct_key,
         acct_profile=acct_profile,
     )
+    return ret
