@@ -3,12 +3,12 @@
 # Stub out the routines around gathering the initial sls file
 # Just use a yaml renderer and get it to where we can manage some basic
 # includes to drive to highdata
-
 # Then we can start to fill out renderers while at the same time
 # deepening the compiler
-
-# Import python libs
 import pathlib
+import sys
+
+from idem.exec.init import ExecReturn
 
 
 def __init__(hub):
@@ -32,7 +32,9 @@ def cli(hub):
     Execute a single idem run from the cli
     """
     hub.pop.config.load(["idem", "acct"], cli="idem")
-    hub.pop.loop.start(hub.idem.init.cli_apply())
+    hub.pop.loop.create()
+    retcode = hub.pop.Loop.run_until_complete(hub.idem.init.cli_apply())
+    sys.exit(retcode)
 
 
 # If the gathering and cli def funcs grow they should be moved to a plugin
@@ -65,13 +67,21 @@ async def cli_apply(hub):
     """
     Run the CLI routine in a loop
     """
-    if hub.SUBPARSER == "state":
-        await hub.idem.init.cli_sls()
-    elif hub.SUBPARSER == "exec":
-        await hub.idem.init.cli_exec()
+    retcode = 0
+
+    try:
+        if hub.SUBPARSER == "state":
+            retcode = await hub.idem.init.cli_sls()
+        elif hub.SUBPARSER == "exec":
+            retcode = await hub.idem.init.cli_exec()
+    finally:
+        if hub.acct.UNLOCKED:
+            await hub.acct.init.close()
+
+    return retcode
 
 
-async def cli_sls(hub):
+async def cli_sls(hub) -> int:
     """
     Execute the cli routine to run states
     """
@@ -93,16 +103,18 @@ async def cli_sls(hub):
 
     errors = hub.idem.RUNS[name]["errors"]
     if errors:
-        display = getattr(hub, "output.nested.display")(errors)
+        display = hub.output.nested.display(errors)
         print(display)
-        return
+        # Return a non-zero error code
+        return len(errors)
     running = hub.idem.RUNS[name]["running"]
-    output = hub.OPT.idem.output
-    display = getattr(hub, f"output.{output}.display")(running)
+    output = hub.OPT.idem.output or "state"
+    display = hub.output[output].display(running)
     print(display)
+    return 0
 
 
-async def cli_exec(hub):
+async def cli_exec(hub) -> int:
     exec_path = hub.OPT.idem.exec_func
     exec_args = hub.OPT.idem.exec_args
     if not exec_path.startswith("exec"):
@@ -122,10 +134,12 @@ async def cli_exec(hub):
         hub.OPT.acct.acct_key,
         hub.OPT.idem.acct_profile,
     )
-    output = hub.OPT.idem.output
-    # exec can't use the idem outputter
-    # TODO in pop-config allow subcommands to have different defaults from their parent
-    if output == "idem":
-        output = "nested"
-    display = getattr(hub, f"output.{output}.display")(ret)
+
+    output = hub.OPT.idem.output or "exec"
+    display = hub.output[output].display(ret)
     print(display)
+
+    if isinstance(ret, ExecReturn):
+        return int(not ret.result)
+
+    return 1
