@@ -1,7 +1,3 @@
-# Import python libs
-import asyncio
-
-
 async def modify(hub, name, chunk):
     """
     Check the state containing the target func and call the aggregate
@@ -11,6 +7,5 @@ async def modify(hub, name, chunk):
     func = hub.idem.rules.init.get_func(name, chunk, "mod_aggregate")
     if func:
         chunk = func(name, chunk)
-        if asyncio.iscoroutine(chunk):
-            chunk = await chunk
+        chunk = await hub.pop.loop.unwrap(chunk)
     return chunk
