@@ -1,10 +1,6 @@
-# Import python libs
-import asyncio
-
-
 async def modify(hub, name, chunk):
     """
-    Take the given run name and low chunk, and allow state pluggins to modify
+    Take the given run name and low chunk, and allow state plugins to modify
     the low chunk
     """
     for mod in hub.idem.mod:
@@ -12,6 +8,5 @@ async def modify(hub, name, chunk):
             continue
         if hasattr(mod, "modify"):
             chunk = mod.modify(name, chunk)
-            if asyncio.iscoroutine(chunk):
-                chunk = await chunk
+            chunk = await hub.pop.loop.unwrap(chunk)
     return chunk
