@@ -1,4 +1,3 @@
-# Import python libs
 import asyncio
 
 
@@ -20,7 +19,12 @@ async def runtime(hub, name, ctx, seq, low, running):
     for ind in inds:
         coros.append(
             hub.idem.rules.init.run(
-                name, ctx, low, seq[ind], running, hub.idem.RUNS[name]["run_num"],
+                name,
+                ctx,
+                low,
+                seq[ind],
+                running,
+                hub.idem.RUNS[name]["run_num"],
             )
         )
         hub.idem.RUNS[name]["run_num"] += 1
